

package { 'curl': ensure => present }

class { 'memcached':
}

class { 'swift::proxy':
  proxy_local_net_ip => '10.35.101.10',
  pipeline           => [
#    'catch_errors',
    'healthcheck',
    'cache',
#    'ratelimit',
    'authtoken',
    'keystone',
    'proxy-server'
  ],
  account_autocreate => true,
}

# configure all of the middlewares
class { [
    'swift::proxy::catch_errors',
    'swift::proxy::healthcheck',
    'swift::proxy::cache',
]: }

class { 'swift::proxy::ratelimit':
    clock_accuracy         => 1000,
    max_sleep_time_seconds => 60,
    log_sleep_time_seconds => 0,
    rate_buffer_seconds    => 5,
    account_ratelimit      => 0
}

class { 'swift::proxy::keystone':
    operator_roles => ['admin', 'SwiftOperator'],
}

class { 'swift::proxy::authtoken':
    admin_user        => 'swift',
    admin_tenant_name => 'services',
    admin_password    => '0c92ee71e7674f12',
    # assume that the controller host is the swift api server
    auth_host         => '10.35.101.10',
}

firewall { '001 swift proxy incoming':
    proto    => 'tcp',
    dport    => ['8080'],
    action   => 'accept',
}


# install all swift storage servers together
class { 'swift::storage::all':
  storage_local_net_ip => '10.35.101.10',
  require => Class['swift'],
}

if(!defined(File['/srv/node'])) {
  file { '/srv/node':
    owner  => 'swift',
    group  => 'swift',
    ensure => directory,
    require => Package['openstack-swift'],
  }
}

swift::ringsync{["account","container","object"]:
    ring_server => '10.35.101.10',
    before => Class['swift::storage::all'],
    require => Class['swift'],
}

firewall { '001 swift storage incoming':
    proto    => 'tcp',
    dport    => ['6000', '6001', '6002', '873'],
    action   => 'accept',
}

File <| |> -> Exec['restorcon']
exec{'restorcon':
    path => '/sbin:/usr/sbin',
    command => 'restorecon -RvF /srv',
}

if ($::selinux != "false"){
    selboolean{'rsync_client':
        value => on,
        persistent => true,
    }
}



swift::storage::loopback { ['device1']:
  base_dir     => '/srv/loopback-device',
  mnt_base_dir => '/srv/node',
  require      => Class['swift'],
  fstype       => 'ext4',
  seek         => '1048576',
}




class { 'ssh::server::install': }

Class['swift'] -> Service <| |>
class { 'swift':
    # not sure how I want to deal with this shared secret
    swift_hash_suffix => 'swift_shared_secret',
    package_ensure    => latest,
}

