

# Ensure Firewall changes happen before libvirt service start
# preventing a clash with rules being set by libvirt
Firewall <| |> -> Class['nova::compute::libvirt']

if $::is_virtual_packstack == "true" {
    $libvirt_type = "qemu"
    nova_config{
        "DEFAULT/libvirt_cpu_mode": value => "none";
    }
}else{
    $libvirt_type = "kvm"
}

package{'python-cinderclient':
    before => Class["nova"]
}

nova_config{
    "DEFAULT/libvirt_inject_partition": value => "-1";
    "DEFAULT/volume_api_class": value => "nova.volume.cinder.API";
}

class {"nova::compute":
    enabled => true,
    vncproxy_host => "10.35.101.10",
    vncserver_proxyclient_address => "10.35.64.69",
}

package { 'qemu-kvm-rhev':
    ensure => present,
    before => Class['nova::compute::libvirt']
}

class { 'nova::compute::libvirt':
  libvirt_type                => "$libvirt_type",
  vncserver_listen            => "10.35.64.69",
}

exec {'load_kvm':
    user => 'root',
    command => '/bin/sh /etc/sysconfig/modules/kvm.modules'
}

Class['nova::compute']-> Exec["load_kvm"]

# Note : remove this once we're installing a version of openstack that isn't
#        supported on RHEL 6.3
if $::is_virtual_packstack == "true" and $::osfamily == "RedHat" and
    $::operatingsystemrelease == "6.3"{
    file { "/usr/bin/qemu-system-x86_64":
        ensure => link,
        target => "/usr/libexec/qemu-kvm",
        notify => Service["nova-compute"],
    }
}

firewall { '001 nova compute incoming':
    proto    => 'tcp',
    dport    => '5900-5999',
    action   => 'accept',
}


# Tune the host with a virtual hosts profile
package {'tuned':
    ensure => present,
}

service {'tuned':
    ensure => running,
    require => Package['tuned'],
}

exec {'tuned-virtual-host':
    unless => '/usr/sbin/tuned-adm active | /bin/grep virtual-host',
    command => '/usr/sbin/tuned-adm profile virtual-host',
    require => Service['tuned'],
}

nova_config{
    "DEFAULT/flat_interface": value => "eth0";
}

# Ensure Firewall changes happen before nova services start
# preventing a clash with rules being set by nova-compute and nova-network
Firewall <| |> -> Class['nova']

nova_config{
    "DEFAULT/metadata_host": value => "10.35.101.10";
    "DEFAULT/sql_connection": value => "mysql://nova@10.35.101.10/nova";
}

class {"nova":
    glance_api_servers => "10.35.101.10:9292",
    qpid_hostname => "10.35.101.10",
    rpc_backend => 'nova.openstack.common.rpc.impl_qpid',
    verbose     => 'True',
}
